.. _murano-pl:

==================
MuranoPL Reference
==================

To develop applications, murano project refers to Murano Programming
Language (MuranoPL). It is represented by easily readable YAML and
YAQL languages. The sections below describe these languages.

.. toctree::
   :maxdepth: 1

   murano_pl/yaml
   murano_pl/yaql
   murano_pl/class_templ
   murano_pl/core_lib
   murano_pl/reflection
   murano_pl/statics
   murano_pl/metadata
   murano_pl/versioning
   murano_pl/actions